| Title: | St.Gallen Tourism Dashboard |
|---|---|
| Description: | St.Gallen Tourism Dashboard R Shiny app. |
| Authors: | Felix Luginbuhl [aut, cre] (ORCID: <https://orcid.org/0009-0008-6625-2899>), Lutz Benson [aut], Fachstelle für Statistik Kanton St.Gallen [cph, fnd] |
| Maintainer: | Felix Luginbuhl <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.5 |
| Built: | 2026-05-25 09:42:56 UTC |
| Source: | https://github.com/statistikSG/sgtourism |
Bounding Box of St.Gallen perimeter map.
bbox_perimeterbbox_perimeter
An object of class numeric of length 4.
Destinationen.
destdest
An object of class sf (inherits from data.frame) with 4 rows and 3 columns.
Gemeinden in den Destinationen.
dest_mundest_mun
An object of class sf (inherits from data.frame) with 122 rows and 3 columns.
Subregionen der Destinationen.
dest_subdest_sub
An object of class sf (inherits from data.frame) with 18 rows and 3 columns.
A subset of official St.Gallen tourism data.
df_ueberblickdf_ueberblick
An object of class tbl_df (inherits from tbl, data.frame) with 11376 rows and 174 columns.
lookup table for region names and corresponding values of var Aggregat in data set.
lookup_aggregatlookup_aggregat
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 48 rows and 2 columns.
Metadata used for country and region names.
meta_countriesmeta_countries
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 80 rows and 4 columns.
Run the Shiny Application
run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |